| Title: | Two-Sample Kuiper Test |
|---|---|
| Description: | This function performs the two-sample Kuiper test to assess the anomaly of continuous, one-dimensional probability distributions. References used for this method are (1). Kuiper, N. H. (1960). <DOI:10.1016/S1385-7258(60)50006-0> and (2). Paltani, S. (2004). <DOI:10.1051/0004-6361:20034220>. |
| Authors: | Ying Ruan [aut, cre] |
| Maintainer: | Ying Ruan <[email protected]> |
| License: | AGPL-3 |
| Version: | 1.0 |
| Built: | 2026-06-05 06:26:38 UTC |
| Source: | https://github.com/cran/kuiper.2samp |
2-sample Kuiper Test Function: performs Kuiper Test for two sets samples of observations
kuiper.2samp(x, y)kuiper.2samp(x, y)
x |
an array of sample observations |
y |
the other array of sample observations |
Kuiper test statistic and p-value
The computation of the p-value takes references from Paltani(2004) which states that the functions (in the set of four formulas) never underestimates the false positive probability however it can be a bit high when the sample size in the range of 40 to 50 a factor of 1.5 is quoted at the 1e-7 level
Kuiper, N. H. (1960). "Tests concerning random points on a circle". Proceedings of the Koninklijke Nederlandse Akademie van Wetenschappen, Series A. 63: 38-47. Paltani, S., "Searching for periods in X-ray observations using Kuiper's test. Application to the ROSAT PSPC archive", Astronomy and Astrophysics, v.240, p.789-790, 2004.
kuiper.2samp(rnorm(1e3),rnorm(1e3))kuiper.2samp(rnorm(1e3),rnorm(1e3))